@@ -4,6 +4,7 @@ Helper functions
 
 from typing import Any, Callable, Union, Sequence
 from functools import wraps
+import platform
 
 
 def return_partial(
@@ -81,3 +82,17 @@ def append(f: Callable[..., Any], *op: Callable[..., Any]) -> Any:
         return rs
 
     return wrapper
+
+
+def is_m1mac() -> bool:
+    """
+    check whether the running platform is MAC with M1 chip
+
+    :return: True for MAC M1 platform
+    :rtype: bool
+    """
+    if platform.processor() != "arm":
+        return False
+    if not platform.platform().startswith("macOS"):
+        return False
+    return True
